==> sqlitestudio-3.0.7.tar.gz: Plugins/SqlEnterpriseFormatter/SqlEnterpriseFormatter_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>QObject</name>
    <message>
        <location filename="sqlenterpriseformatter.cpp" line="91"/>
        <location filename="sqlenterpriseformatter.cpp" line="98"/>
        <source>name</source>
        <comment>example name wrapper</comment>
        <translation>Nom</translation>
    </message>
</context>
<context>
    <name>SqlEnterpriseFormatter</name>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="46"/>
        <source>Indentation</source>
        <translation>Identation</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="58"/>
        <source>Line up keywords in multi-line queries</source>
        <translation>Ligne de most clé en majuscule dans une requête multiligne</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="68"/>
        <source>Indent contents of parenthesis block</source>
        <translation>Indenté le contenu du block entre parenthèses</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="91"/>
        <source>Tab size:</source>
        <translation>Dimension Tab:</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="106"/>
        <source>New lines</source>
        <translation>Nouvelles lignes</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="160"/>
        <source>Before opening parenthesis in column definitions</source>
        <translation>Avant l&apos;ouverture des parenthèses dans la définition de la colonne</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="170"/>
        <source>After opening parenthesis in column definitions</source>
        <translation>Après l&apos;ouverture des parenthèses dans la définition de la colonne</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="180"/>
        <source>Before closing parenthesis in column definitions</source>
        <translation>Avant la fermeture des parenthèses dans la définition de la colonne</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="190"/>
        <source>After closing parenthesis in column definitions</source>
        <translation>Après la fermeture des parenthèses dans la définition de la colonne</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="200"/>
        <source>Before opening parenthesis in expressions</source>
        <translation>Avant l&apos;ouverture des parenthèses dans l&apos;expression</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="210"/>
        <source>After opening parenthesis in expressions</source>
        <translation>Après l&apos;ouverture des parenthèses dans l&apos;expression</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="220"/>
        <source>Before closing parenthesis in expressions</source>
        <translation>Avant la fermeture des parenthèses dans l&apos;expression</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="230"/>
        <source>After closing parenthesis in expressions</source>
        <translation>Après la fermeture des parenthèses dans l&apos;expression</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="240"/>
        <source>After JOIN keywords in FROM clause</source>
        <translation>Après le mot clé JOIN dans la clause FROM</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="250"/>
        <source>Put each column constraint in CREATE TABLE into new line</source>
        <translation>Mettez chaque contrainte de colonne dans CREATE TABLE à une nouvelleligne</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="260"/>
        <source>After comma</source>
        <translation>Après virgule</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="270"/>
        <source>After comma in expressions</source>
        <translation>Après la virgule dans l&apos;exoression</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="280"/>
        <source>After semicolon</source>
        <translation>Après un point virgule</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="290"/>
        <location filename="sqlenterpriseformatter.ui" line="512"/>
        <source>Never before semicolon</source>
        <translation>Jamais avant un point virgule</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="338"/>
        <source>White spaces</source>
        <translation>Espaces</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="392"/>
        <source>Before comma in lists</source>
        <translation>Après virgule dans la liste</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="402"/>
        <source>After comma in lists</source>
        <translation>Avant virgule dans la liste</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="412"/>
        <source>Before opening parenthesis</source>
        <translation>Avant l&apos;ouverture des parenthèses</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="422"/>
        <source>After opening parenthesis</source>
        <translation>Après l&apos;ouverture des parenthèses</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="432"/>
        <source>Before closing parenthesis</source>
        <translation>Avant la fermeture des parenthèses</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="442"/>
        <source>After closing parenthesis</source>
        <translation>Après la fermeture des parenthèses</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="452"/>
        <source>No space between SQL function name and opening parenthesis</source>
        <translation>aucun espance entre le nom de la fonction SQL et l&apos;ouverture des paranthèses</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="462"/>
        <source>Before dot operator (in path to database object)</source>
        <translation>Avant le point (dans le chemin de la base de données)</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="472"/>
        <source>After dot operator (in path to database object)</source>
        <translation>Après </translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="482"/>
        <source>Before mathematical operator</source>
        <translation>Avant opérateurmathématique</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="492"/>
        <source>After mathematical operator</source>
        <translation>Après opérateurmathématique</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="502"/>
        <source>Never before comma</source>
        <translation>Jamais avant virgule</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="558"/>
        <source>Names</source>
        <translation>noms</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="583"/>
        <source>Preferred name wrapper</source>
        <translation>Preferred name wrapper</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="600"/>
        <source>Always use name wrapping</source>
        <translation>Always use name wrapping</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="610"/>
        <source>Uppercase data type names</source>
        <translation>Nom de type de données en majuscule</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="620"/>
        <source>Uppercase keywords</source>
        <translation>Mots clé en majuscule</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="631"/>
        <source>Comments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="637"/>
        <source>Preferred comment marker (where possible):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="647"/>
        <source>SqlEnterpriseFormatter.CommentMarkers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="654"/>
        <source>Move all comments to the line end</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="664"/>
        <source>Line up comments at the line end</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="695"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
</context>
</TS>

==> sqlitestudio_3.1.0.orig.tar.gz: Plugins/SqlEnterpriseFormatter/SqlEnterpriseFormatter_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>QObject</name>
    <message>
        <location filename="sqlenterpriseformatter.cpp" line="91"/>
        <location filename="sqlenterpriseformatter.cpp" line="98"/>
        <source>name</source>
        <comment>example name wrapper</comment>
        <translation>Nom</translation>
    </message>
</context>
<context>
    <name>SqlEnterpriseFormatter</name>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="46"/>
        <source>Indentation</source>
        <translation>Identation</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="58"/>
        <source>Line up keywords in multi-line queries</source>
        <translation>Ligne de most clé en majuscule dans une requête multiligne</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="68"/>
        <source>Indent contents of parenthesis block</source>
        <translation>Indenté le contenu du block entre parenthèses</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="91"/>
        <source>Tab size:</source>
        <translation>Dimension Tab:</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="106"/>
        <source>New lines</source>
        <translation>Nouvelles lignes</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="160"/>
        <source>Before opening parenthesis in column definitions</source>
        <translation>Avant l&rsquo;ouverture des parenthèses dans la définition de la colonne</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="170"/>
        <source>After opening parenthesis in column definitions</source>
        <translation>Après l&rsquo;ouverture des parenthèses dans la définition de la colonne</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="180"/>
        <source>Before closing parenthesis in column definitions</source>
        <translation>Avant la fermeture des parenthèses dans la définition de la colonne</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="190"/>
        <source>After closing parenthesis in column definitions</source>
        <translation>Après la fermeture des parenthèses dans la définition de la colonne</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="200"/>
        <source>Before opening parenthesis in expressions</source>
        <translation>Avant l&rsquo;ouverture des parenthèses dans l&rsquo;expression</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="210"/>
        <source>After opening parenthesis in expressions</source>
        <translation>Après l&rsquo;ouverture des parenthèses dans l&rsquo;expression</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="220"/>
        <source>Before closing parenthesis in expressions</source>
        <translation>Avant la fermeture des parenthèses dans l&rsquo;expression</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="230"/>
        <source>After closing parenthesis in expressions</source>
        <translation>Après la fermeture des parenthèses dans l&rsquo;expression</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="240"/>
        <source>After JOIN keywords in FROM clause</source>
        <translation>Après le mot clé JOIN dans la clause FROM</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="250"/>
        <source>Put each column constraint in CREATE TABLE into new line</source>
        <translation>Mettez chaque contrainte de colonne dans CREATE TABLE à une nouvelleligne</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="260"/>
        <source>After comma</source>
        <translation>Après virgule</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="270"/>
        <source>After comma in expressions</source>
        <translation>Après la virgule dans l&rsquo;exoression</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="280"/>
        <source>After semicolon</source>
        <translation>Après un point virgule</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="290"/>
        <location filename="sqlenterpriseformatter.ui" line="512"/>
        <source>Never before semicolon</source>
        <translation>Jamais avant un point virgule</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="338"/>
        <source>White spaces</source>
        <translation>Espaces</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="392"/>
        <source>Before comma in lists</source>
        <translation>Après virgule dans la liste</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="402"/>
        <source>After comma in lists</source>
        <translation>Avant virgule dans la liste</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="412"/>
        <source>Before opening parenthesis</source>
        <translation>Avant l&rsquo;ouverture des parenthèses</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="422"/>
        <source>After opening parenthesis</source>
        <translation>Après l&rsquo;ouverture des parenthèses</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="432"/>
        <source>Before closing parenthesis</source>
        <translation>Avant la fermeture des parenthèses</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="442"/>
        <source>After closing parenthesis</source>
        <translation>Après la fermeture des parenthèses</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="452"/>
        <source>No space between SQL function name and opening parenthesis</source>
        <translation>aucun espance entre le nom de la fonction SQL et l&rsquo;ouverture des paranthèses</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="462"/>
        <source>Before dot operator (in path to database object)</source>
        <translation>Avant le point (dans le chemin de la base de données)</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="472"/>
        <source>After dot operator (in path to database object)</source>
        <translation>Après </translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="482"/>
        <source>Before mathematical operator</source>
        <translation>Avant opérateurmathématique</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="492"/>
        <source>After mathematical operator</source>
        <translation>Après opérateurmathématique</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="502"/>
        <source>Never before comma</source>
        <translation>Jamais avant virgule</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="558"/>
        <source>Names</source>
        <translation>noms</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="583"/>
        <source>Preferred name wrapper</source>
        <translation>Preferred name wrapper</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="600"/>
        <source>Always use name wrapping</source>
        <translation>Always use name wrapping</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="610"/>
        <source>Uppercase data type names</source>
        <translation>Nom de type de données en majuscule</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="620"/>
        <source>Uppercase keywords</source>
        <translation>Mots clé en majuscule</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="631"/>
        <source>Comments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="637"/>
        <source>Preferred comment marker (where possible):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="647"/>
        <source>SqlEnterpriseFormatter.CommentMarkers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="654"/>
        <source>Move all comments to the line end</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="664"/>
        <source>Line up comments at the line end</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="695"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
</context>
</TS>
